engine

package module
v0.0.0-...-be8aba7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2021 License: MIT Imports: 3 Imported by: 2

README

Go Report Card

clouddesc

Engine

CloudDesc helps you describe your cloud and output detailed reports on all your cloud based assets. Perfect for reporting, auditing, and onboarding new-starters. CloudDesc aims to be open-source and self-hosted, however, if you do not want to self-host you can use our cloud service available here.

Getting Started

With docker installed, run the below command to start a local Temporal.io server and database.

docker-compose up --build --force-recreate

You can now start the Worker

go run cmd/worker/main.go

You can now trigger the starter to mock a request

go run cmd/starter/main.go

Clean up by removing the temporal server composition:

docker-compose down

Documentation

Index

Constants

const TaskQueue = "TASK_QUEUE"

Variables

This section is empty.

Functions

func Activity

func Activity(name string) (string, error)

func Workflow

func Workflow(ctx workflow.Context, name string) (string, error)

Types

This section is empty.

Directories

Path Synopsis
cmd
starter command
worker command

Jump to